==========================================
Welcome to Freezer's client documentation!
==========================================

Contents
--------

.. toctree::
   :maxdepth: 2

   user/index
   reference/index
   cli/index
   contributor/index


Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`


